Lang

Enum Lang 

#[non_exhaustive]
pub enum Lang {
Show 48 variants Afrikaans, Albanian, Assamese, Belarusian, Bengali, Bulgarian, Catalan, Croatian, Czech, Danish, Dutch, English, Estonian, Finnish, French, Galician, Georgian, German, Greek, Gujarati, Hindi, Hungarian, Icelandic, Italian, Kannada, Kurmanji, Latin, Lithuanian, Malayalam, Marathi, Mongolian, Norwegian, Oriya, Panjabi, Polish, Portuguese, Russian, Sanskrit, Serbian, Slovak, Slovenian, Spanish, Swedish, Tamil, Telugu, Turkish, Turkmen, Ukrainian,
}
A language you can hyphenate in.

Lists for each language also the ISO 639-1 two letter language code and the ISO 15924 four letter script code.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Afrikaans

Hyphenation for Afrikaans. (Code: af, Script, Latn, Feature: afrikaans)



Albanian

Hyphenation for Albanian. (Code: sq, Script, Latn, Feature: albanian)



Assamese

Hyphenation for Assamese. (Code: as, Script, Beng, Feature: assamese)



Belarusian

Hyphenation for Belarusian. (Code: be, Script, Cyrl, Feature: belarusian)



Bengali

Hyphenation for Bengali. (Code: bn, Script, Beng, Feature: bengali)



Bulgarian

Hyphenation for Bulgarian. (Code: bg, Script, Cyrl, Feature: bulgarian)



Catalan

Hyphenation for Catalan. (Code: ca, Script, Latn, Feature: catalan)



Croatian

Hyphenation for Croatian. (Code: hr, Script, Latn, Feature: croatian)



Czech

Hyphenation for Czech. (Code: cs, Script, Latn, Feature: czech)



Danish

Hyphenation for Danish. (Code: da, Script, Latn, Feature: danish)



Dutch

Hyphenation for Dutch. (Code: nl, Script, Latn, Feature: dutch)



English

Hyphenation for English. (Code: en, Script, Latn, Feature: english)



Estonian

Hyphenation for Estonian. (Code: et, Script, Latn, Feature: estonian)



Finnish

Hyphenation for Finnish. (Code: fi, Script, Latn, Feature: finnish)



French

Hyphenation for French. (Code: fr, Script, Latn, Feature: french)



Galician

Hyphenation for Galician. (Code: gl, Script, Latn, Feature: galician)



Georgian

Hyphenation for Georgian. (Code: ka, Script, Geor, Feature: georgian)



German

Hyphenation for German. (Code: de, Script, Latn, Feature: german)



Greek

Hyphenation for Greek. (Code: el, Script, Grek, Feature: greek)



Gujarati

Hyphenation for Gujarati. (Code: gu, Script, Gujr, Feature: gujarati)



Hindi

Hyphenation for Hindi. (Code: hi, Script, Deva, Feature: hindi)



Hungarian

Hyphenation for Hungarian. (Code: hu, Script, Latn, Feature: hungarian)



Icelandic

Hyphenation for Icelandic. (Code: is, Script, Latn, Feature: icelandic)



Italian

Hyphenation for Italian. (Code: it, Script, Latn, Feature: italian)



Kannada

Hyphenation for Kannada. (Code: kn, Script, Knda, Feature: kannada)



Kurmanji

Hyphenation for Kurmanji. (Code: ku, Script, Latn, Feature: kurmanji)



Latin

Hyphenation for Latin. (Code: la, Script, Latn, Feature: latin)



Lithuanian

Hyphenation for Lithuanian. (Code: lt, Script, Latn, Feature: lithuanian)



Malayalam

Hyphenation for Malayalam. (Code: ml, Script, Mlym, Feature: malayalam)



Marathi

Hyphenation for Marathi. (Code: mr, Script, Deva, Feature: marathi)



Mongolian

Hyphenation for Mongolian. (Code: mn, Script, Cyrl, Feature: mongolian)



Norwegian

Hyphenation for Norwegian. (Code: no, Alias: nb, Alias: nn, Script, Latn, Feature: norwegian)



Oriya

Hyphenation for Oriya. (Code: or, Script, Orya, Feature: oriya)



Panjabi

Hyphenation for Panjabi. (Code: pa, Script, Guru, Feature: panjabi)



Polish

Hyphenation for Polish. (Code: pl, Script, Latn, Feature: polish)



Portuguese

Hyphenation for Portuguese. (Code: pt, Script, Latn, Feature: portuguese)



Russian

Hyphenation for Russian. (Code: ru, Script, Cyrl, Feature: russian)



Sanskrit

Hyphenation for Sanskrit. (Code: sa, Script, Deva, Feature: sanskrit)



Serbian

Hyphenation for Serbian. (Code: sr, Script, Cyrl, Feature: serbian)



Slovak

Hyphenation for Slovak. (Code: sk, Script, Latn, Feature: slovak)



Slovenian

Hyphenation for Slovenian. (Code: sl, Script, Latn, Feature: slovenian)



Spanish

Hyphenation for Spanish. (Code: es, Script, Latn, Feature: spanish)



Swedish

Hyphenation for Swedish. (Code: sv, Script, Latn, Feature: swedish)



Tamil

Hyphenation for Tamil. (Code: ta, Script, Taml, Feature: tamil)



Telugu

Hyphenation for Telugu. (Code: te, Script, Telu, Feature: telugu)



Turkish

Hyphenation for Turkish. (Code: tr, Script, Latn, Feature: turkish)



Turkmen

Hyphenation for Turkmen. (Code: tk, Script, Latn, Feature: turkmen)



Ukrainian

Hyphenation for Ukrainian. (Code: uk, Script, Cyrl, Feature: ukrainian)

Implementations

Source

impl Lang

pub fn from_iso(code: [u8; 2]) -> Option<Self>

Select a language using its ISO 639-1 code.

pub fn bounds(self) -> (usize, usize)

The default number of chars to each side between which breaking is forbidden.

This follows typographic conventions.

pub fn hyphenation_character(self) -> Option<char>

The default character used to join syllables.

Returns Some('\u{ad}') (SOFT HYPHEN) for most languages, but None for Indic scripts where visual hyphenation is not conventional.